@@ -51,6 +51,16 @@ def datetime_toChinStr_dil(dt: datetime) -> str:
     return dt.strftime("%Y年%m月%d日 %H时%M分%S秒")
 
 
+def datetime_toCustStr(dt: datetime, fmat: str) -> str:
+    """
+    把datetime转成自定义字符串
+    :param dt: datetime.datetime.now
+    fmat: "%Y-%m-%d"  "%Y-%m-%d %H:%M:%S" "%Y年%m月%d日" "%Y年%m月%d日 %H时%M分%S秒"
+    :return:
+    """
+    return dt.strftime(fmat)
+
+
 def get_now_date():
     """
     获取今日日期字符串
